smartcard.ReaderMonitoring.ReaderObserver

# ``smartcard`.`ReaderMonitoring`.`ReaderObserver``

class documentation

`class ReaderObserver(Observer):`

Known subclasses: `smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer`, `smartcard.wx.ReaderToolbar.ReaderComboBox`, `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver`

View In Hierarchy

ReaderObserver is a base abstract class for objects that are to be notified upon smartcard reader insertion/removal.

Method | `__init__` | Undocumented
Method | `update` | Called upon reader insertion/removal.

def __init__(self):
overridden in `smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer`, `smartcard.wx.ReaderToolbar.ReaderComboBox`, `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver`

Undocumented

def update(self, observable, handlers):
overrides `smartcard.Observer.Observer.update`
overridden in `smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer`, `smartcard.wx.ReaderToolbar.ReaderComboBox`, `smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver`

Called upon reader insertion/removal.

Parameters
observable |
handlers | addedreaders: list of added readers causing notification removedreaders: list of removed readers causing notification